==> hecplus-0.1.0.tar.gz: hecplus-0.1.0/setup.py <==
from setuptools import setup, find_packages
from hecplus.__init__ import __version__

setup(
    name='hecplus',
    version=__version__,
    author='Prashana Bajracharya',
    author_email='pajracharya713@gmail.com',
    description='Helper functions for data science applications.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    # author=httpimport.__author__,
    # license='MIT',
    # url=httpimport.__github__,
    # py_modules=['dsplus'],
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'License :: OSI Approved :: MIT License',
        # 'Operating System :: OS Independent',
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        # 'Programming Language :: Python :: Implementation :: CPython',
        # 'Programming Language :: Python :: Implementation :: PyPy',
        # 'Intended Audience :: Developers',
        # 'Intended Audience :: Information Technology',
        # 'Intended Audience :: Education',
        'Topic :: Scientific/Engineering :: Hydrology',
    ],
    python_requires='>=3.10',
    install_requires=[
        'dsplus>=0.4.9',
        'pandas>=2.0',
        'h5py>=3.10.0',
        'pydsstools>=2.3.1',
    ],
    keywords=[
        'hec',
        'hecras',
        'hechms'],
)

==> hecplus-0.1.1.tar.gz: hecplus-0.1.1/setup.py <==
from setuptools import setup, find_packages
from hecplus.__init__ import __version__

setup(
    name='hecplus',
    version=__version__,
    author='Prashana Bajracharya',
    author_email='pajracharya713@gmail.com',
    description='Helper functions for working with Hydrologic Engineering Center (HEC) softwares',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    # author=httpimport.__author__,
    # license='MIT',
    # url=httpimport.__github__,
    # py_modules=['dsplus'],
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'License :: OSI Approved :: MIT License',
        # 'Operating System :: OS Independent',
        'Development Status :: 4 - Beta',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        # 'Programming Language :: Python :: Implementation :: CPython',
        # 'Programming Language :: Python :: Implementation :: PyPy',
        # 'Intended Audience :: Developers',
        # 'Intended Audience :: Information Technology',
        # 'Intended Audience :: Education',
        'Topic :: Scientific/Engineering :: Hydrology',
    ],
    python_requires='>=3.10',
    install_requires=[
        'dsplus>=0.4.9',
        'pandas>=2.0',
        'h5py>=3.10.0',
        'pydsstools>=2.3.1',
    ],
    keywords=[
        'hec',
        'hecras',
        'hechms'],
)
